==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebHeadSelectorTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebHeadSelectorTemplateDetailsDescriptionMetadata } from "./WebHeadSelectorTemplateDetailsDescriptionMetadata";
import { WebHeadSelectorTemplateContextDescription } from "./WebHeadSelectorTemplateContextDescription";
/**
 * @hidden
 */
var WebHeadSelectorTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebHeadSelectorTemplateContextDescriptionMetadata, _super);
    function WebHeadSelectorTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebHeadSelectorTemplateContextDescriptionMetadata.b = function (a) {
        if (WebHeadSelectorTemplateContextDescriptionMetadata.a == null) {
            WebHeadSelectorTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebHeadSelectorTemplateContextDescriptionMetadata.c(WebHeadSelectorTemplateContextDescriptionMetadata.a);
        }
        if (a.j(WebHeadSelectorTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.y(WebHeadSelectorTemplateContextDescriptionMetadata.a);
        WebHeadSelectorTemplateDetailsDescriptionMetadata.d(a);
    };
    WebHeadSelectorTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:HeadSelectorTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Implicit", "ExportedType:WebHeadSelectorTemplateDetails");
    };
    WebHeadSelectorTemplateContextDescriptionMetadata.d = function (a) {
        WebHeadSelectorTemplateContextDescriptionMetadata.b(a);
        a.aa("WebHeadSelectorTemplateContext", function () { return new WebHeadSelectorTemplateContextDescription(); });
        a.z("WebHeadSelectorTemplateContext", WebHeadSelectorTemplateContextDescriptionMetadata.a);
    };
    WebHeadSelectorTemplateContextDescriptionMetadata.$t = markType(WebHeadSelectorTemplateContextDescriptionMetadata, 'WebHeadSelectorTemplateContextDescriptionMetadata');
    WebHeadSelectorTemplateContextDescriptionMetadata.a = null;
    return WebHeadSelectorTemplateContextDescriptionMetadata;
}(Base));
export { WebHeadSelectorTemplateContextDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebHeadSelectorTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebHeadSelectorTemplateDetailsDescriptionMetadata } from "./WebHeadSelectorTemplateDetailsDescriptionMetadata";
import { WebHeadSelectorTemplateContextDescription } from "./WebHeadSelectorTemplateContextDescription";
/**
 * @hidden
 */
var WebHeadSelectorTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebHeadSelectorTemplateContextDescriptionMetadata, _super);
    function WebHeadSelectorTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebHeadSelectorTemplateContextDescriptionMetadata.b = function (a) {
        if (WebHeadSelectorTemplateContextDescriptionMetadata.a == null) {
            WebHeadSelectorTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebHeadSelectorTemplateContextDescriptionMetadata.c(WebHeadSelectorTemplateContextDescriptionMetadata.a);
        }
        if (a.k(WebHeadSelectorTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebHeadSelectorTemplateContextDescriptionMetadata.a);
        WebHeadSelectorTemplateDetailsDescriptionMetadata.d(a);
    };
    WebHeadSelectorTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:HeadSelectorTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Implicit", "ExportedType:WebHeadSelectorTemplateDetails");
    };
    WebHeadSelectorTemplateContextDescriptionMetadata.d = function (a) {
        WebHeadSelectorTemplateContextDescriptionMetadata.b(a);
        a.ac("WebHeadSelectorTemplateContext", function () { return new WebHeadSelectorTemplateContextDescription(); });
        a.ab("WebHeadSelectorTemplateContext", WebHeadSelectorTemplateContextDescriptionMetadata.a);
    };
    WebHeadSelectorTemplateContextDescriptionMetadata.$t = markType(WebHeadSelectorTemplateContextDescriptionMetadata, 'WebHeadSelectorTemplateContextDescriptionMetadata');
    WebHeadSelectorTemplateContextDescriptionMetadata.a = null;
    return WebHeadSelectorTemplateContextDescriptionMetadata;
}(Base));
export { WebHeadSelectorTemplateContextDescriptionMetadata };
